/*------------------------------------------------------------------------------
--  This file is a part of the SocExplorer Software
--  Copyright (C) 2011, Plasma Physics Laboratory - CNRS
--
--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-------------------------------------------------------------------------------*/
/*--                  Author : Alexis Jeandet
--                     Mail : alexis.jeandet@lpp.polytechnique.fr
----------------------------------------------------------------------------*/
#include "ahbuartpluginui.h"
#include "ui_ahbuartpluginui.h"

ahbUartPluginUI::ahbUartPluginUI(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::ahbUartPluginUI)
{
    ui->setupUi(this);
    connect(ui->OpenPort,SIGNAL(clicked()),this,SLOT(connectPort()));
    connect(ui->PortspeedSlider,SIGNAL(valueChanged(int)),ui->baurateLCD,SLOT(display(int)));
    connect(ui->rescanPorts,SIGNAL(clicked()),this,SIGNAL(rescanPorts()));
    this->writtenBytes = 0;
    this->readBytes = 0;
}

void ahbUartPluginUI::connectPort()
{
    emit this->connectPortsig(ui->PortName->text(),ui->PortspeedSlider->value());
}

void ahbUartPluginUI::setConnected(bool connected)
{
    if(connected == true)
    {
        ui->OpenPort->setText(tr("Close port"));
    }
    else
        ui->OpenPort->setText(tr("Open port"));
}


ahbUartPluginUI::~ahbUartPluginUI()
{
    delete ui;
}


void ahbUartPluginUI::setconfig(QString PortName, int baudrate)
{
    this->ui->PortName->setText(PortName);
    this->ui->PortspeedSlider->setValue(baudrate);
}

void ahbUartPluginUI::addWritenBytes(int count)
{
    this->writtenBytes+=count;
    this->ui->WrBytesLCD->display(this->writtenBytes);
}

void ahbUartPluginUI::addReadBytes(int count)
{
    this->readBytes+=count;
    this->ui->RdBytesLCD->display(this->readBytes);
}


void ahbUartPluginUI::setCompleter(QCompleter *completer)
{
    this->ui->PortName->setCompleter(completer);
}

void ahbUartPluginUI::closeEvent(QCloseEvent *event)
{
    event->accept();
}






